tapcamd

package
v0.0.0-...-0f19a68 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 29, 2016 License: MIT Imports: 5 Imported by: 0

Documentation

Overview

Package tapcamd provides a SSH and SFTP server for the tapcamd service.

Index

Constants

This section is empty.

Variables

var (
	// ErrNoConfig is returned when a nil SSH server configuration is specified
	// when New is called.
	ErrNoConfig = errors.New("no SSH server configuration specified")
)

Functions

This section is empty.

Types

type Server

type Server struct {
	// contains filtered or unexported fields
}

A Server is a SSH and SFTP server for the tapcamd service. It can be used to start a listener to accept SFTP connections, using authentication mechanisms specified when passing a *ssh.ServerConfig.

func New

func New(host string, config *ssh.ServerConfig) (*Server, error)

New creates a new SSH and SFTP server which listens on the specified address and accepts a *ssh.ServerConfig to configure the underlying SSH server's properties and authentication mechanisms.

func (*Server) ListenAndServe

func (s *Server) ListenAndServe() error

ListenAndServe begins serving SSH and SFTP connections.

Jump to