Documentation
¶
Overview ¶
Package tapcamclient provides a client for the tapcamd service.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Client ¶
type Client struct {
// contains filtered or unexported fields
}
A Client is a client for the tapcamd service. It currently makes use of SFTP to upload images to tapcamd, but this may change in the future.
func New ¶
New creates a new Client using the input host and zero or more optional Option functions.
At a minimum, the SSHUserKeyFile Option must be specified to allow authentication and image upload.
type Option ¶
An Option is a function which can apply configuration to a Client.
func SSHUserKeyFile ¶
SSHUserKeyFile configures a Client to use an SSH username and private key file to authenticate against a tapcamd server.
Click to show internal directories.
Click to hide internal directories.